🔝💯
Input table
| Parameter                                                           | File type                               | Required?           | Default Path                                                                  | Description             |
|----------------------------------------------------------------|--------------------------------------|------------------------|-------------------------------------------------------------------------|--------------------------|
| fastqs                                                                   | .fastq or List[.fastq] or .txt   | True                    | N/A                                                                                 | ...                             |
| index                                                                     | .idx                                     | True                    | N/A                                                                                 | ...                             |
| t2g                                                                       | .txt                                       | True                    | N/A                                                                                 | ...                             |
| reference_genome_index                                   | .idx                                       | False                  | `out`/reference_genome_index.idx                                | Only created when it does not exist and when adata_reference_genome will be used in vk clean                             |
| reference_genome_t2g                                       | .txt                                       | False                  | `out`/reference_genome_t2g.txt                                    | Only created when it does not exist and when adata_reference_genome will be used in vk clean                             |
| adata_reference_genome                                   | .h5ad                                   | False                  | N/A                                                                                 | Only created when it does not exist and it will be used in vk clean                             |
| kb_count_reference_genome_dir                        | directory                              | False                  | N/A                                                                                 | Only created when it does not exist and it will be used in vk clean                               |
| vk_ref_dir                                                              | directory                             | False                  | N/A                                                                                 |                                |
| vcrs_fasta                                                            | .fasta                                   | False                  | <vk_ref_dir>/vcrs_filtered.fa                                         |                                |
| id_to_header_csv                                                 | .csv                                      | False                  | <vk_ref_dir>/id_to_header_mapping_filtered.csv         |                                |
| dlist_fasta                                                             | .fasta                                   | False                  | <vk_ref_dir>/dlist_filtered.fa                                           |                               |
| variants_updated_csv                                        | .csv                                    | False                  | <vk_ref_dir>/variants_updated_filtered.csv           |                               |


Output table
| Parameter                                                           | File type         | Flag                                                                           | Default Path                                                                                                     | Description           |
|----------------------------------------------------------------|--------------------|---------------------------------------------------------------------|------------------------------------------------------------------------------------------------------|-------------------------|
| out                                                                       | directory         | N/A                                                                            | "."                                                                                                                     | ...                          |
| kb_count_vcrs_out_dir                  					  | directory         | N/A                                                                            | <out>/kb_count_out_vcrs												                                  | ...                          |
| kb_count_reference_genome_out_dir         		  | directory        | N/A                                                                             | <out>/kb_count_out_reference_genome                       						              | ...                          |
| vk_summarize_out_dir                              		  | directory         | N/A                                                                            | <out>/vk_summarize                       																  | ...                          |
| adata_vcrs_clean_out                  	                      | .h5ad             | N/A                                                                             | <out>/adata_cleaned.h5ad									                                              | ...                          |
| adata_reference_genome_clean_out                 | .h5ad             | adata_reference_genome or kb_count_reference_genome_dir must be provided             | <out>/adata_reference_genome_cleaned.h5ad	   | ...                          |
| vcf_out                  	                                              | .vcf                 | save_vcf                                                                    | <out>/vcrs.vcf												                                                      | ...                          |

